@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,13 +25,11 @@
 #ifndef ABOUT_SE_WIDGET_H
 #define ABOUT_SE_WIDGET_H
 
-#include <QWidget>
 #include "ui_aboutsewidget.h"
 
 class AboutSEWidget: public QWidget, public Ui::AboutSEWidget {
-	private:
-		Q_OBJECT
-		
+	Q_OBJECT
+
 	public:
 		AboutSEWidget(QWidget *parent = nullptr);
 };
