@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include "rule.h"
 #include "index.h"
 #include "genericsql.h"
+#include "pgsqltypes/checkoptiontype.h"
 
 class __libcore View: public BaseTable {
 	private:
@@ -50,15 +51,24 @@ class __libcore View: public BaseTable {
 		with_no_data,
 
 		//! \brief Indicates that the view is a a recursive one. This setting is auto exclusive with 'materialized'
-		recursive;
+		recursive,
+
+		security_invoker,
+
+		security_barrier;
+
+		CheckOptionType check_option;
 
 		void setSQLObjectAttribute();
 
+		void setOptionsAttributes(SchemaParser::CodeType def_type);
+
 		//! \brief Returns a unique name for a columns comparing it to the existent columns. In case of duplication the name receives a suffix
 		QString getUniqueColumnName(const QString &name);
 
 	public:
 		static const QString ExtraSCRegExp;
+
 		View();
 
 		virtual ~View();
@@ -70,15 +80,20 @@ class __libcore View: public BaseTable {
 		void setMaterialized(bool value);
 		void setRecursive(bool value);
 		void setWithNoData(bool value);
+		void setSecurityBarrier(bool value);
+		void setSecurityInvoker(bool value);
+
+		void setCheckOption(CheckOptionType check_opt);
+		CheckOptionType getCheckOption();
 
 		bool isMaterialized();
 		bool isRecursive();
 		bool isWithNoData();
+		bool isSecurityInvoker();
+		bool isSecurityBarrier();
 
 		void setReferences(const std::vector<Reference> &obj_refs);
-
 		void setCustomColumns(const std::vector<SimpleColumn> &cols);
-
 		void setSqlDefinition(const QString &sql_def);
 
 		QString getSqlDefinition();
@@ -202,7 +217,7 @@ class __libcore View: public BaseTable {
 
 		std::vector<BaseTable *> getReferencedTables();
 
-		virtual QString getDataDictionary(bool split, const attribs_map &extra_attribs = {}) override;
+		virtual QString getDataDictionary(bool split, bool md_format, const attribs_map &extra_attribs = {}) override;
 
 		virtual QString getAlterCode(BaseObject *object) final;
 
@@ -210,6 +225,8 @@ class __libcore View: public BaseTable {
 		void operator = (View &visao);
 
 		virtual void updateDependencies() override;
+
+		bool acceptsReplaceCommand() override;
 };
 
 #endif
