@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,19 +25,22 @@
 #ifndef MODEL_FIX_FORM_H
 #define MODEL_FIX_FORM_H
 
-#include <QtWidgets>
+#include <QProcess>
 #include "ui_modelfixform.h"
 #include "widgets/fileselectorwidget.h"
+#include "widgets/debugoutputwidget.h"
 
 class __libgui ModelFixForm: public QDialog, public Ui::ModelFixForm {
-	private:
-		Q_OBJECT
+	Q_OBJECT
 
+	private:
 		static const QString PgModelerCli;
 
 		//! \brief Process used to execute pgmodeler-cli
 		QProcess pgmodeler_cli_proc;
 
+		DebugOutputWidget *dbg_output_wgt;
+
 		FileSelectorWidget *input_file_sel,
 		*output_file_sel,
 		*pgmodeler_cli_sel;
