@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,14 +26,12 @@
 #define ABOUT_WIDGET_H
 
 #include "guiglobal.h"
-#include <QWidget>
 #include <QGraphicsDropShadowEffect>
 #include "ui_aboutwidget.h"
 
 class __libgui AboutWidget: public QWidget, public Ui::AboutWidget {
-	private:
-		Q_OBJECT
-		
+	Q_OBJECT
+
 	public:
 		AboutWidget(QWidget *parent = nullptr);
 		
