@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2025 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,8 +21,7 @@
 #include "pgmodelerunittest.h"
 
 class SchemaFilesSyntaxTest: public QObject, public PgModelerUnitTest {
-	private:
-		Q_OBJECT
+	Q_OBJECT
 
 	public:
 		SchemaFilesSyntaxTest() : PgModelerUnitTest(SCHEMASDIR) {}
@@ -68,7 +67,8 @@ void SchemaFilesSyntaxTest::schemasDontGenerateSyntaxErrors()
 				QFAIL(e.getErrorMessage().toStdString().c_str());
 			}
 
-			QWARN(e.getErrorMessage().toStdString().c_str());
+			QTextStream out(stdout);
+			out << e.getErrorMessage() << Qt::endl;
 		}
 	}
 }
